==> geary_0.12.4.orig.tar.xz: geary-0.12.4/README.md <==

Geary: Send and receive email
=============================

Geary is an email application built around conversations, for the
GNOME 3 desktop. It allows you to read, find and send email with a
straightforward, modern interface.

Visit https://wiki.gnome.org/Apps/Geary for more information.

**GitHub users please note**: Bug reports, code contributions and
translations are managed using GNOME's infrastructure, so we cannot
accept tickets or pull requests on GitHub. Please see the links below
for more information.

![Geary displaying a conversation](https://wiki.gnome.org/Apps/Geary?action=AttachFile&amp;do=get&amp;target=geary-conversation-0.12.png)

Installation & Licensing
------------------------

Please consult the [INSTALL](./INSTALL) and [COPYING](./COPYING) files
for more information.

Contributing to Geary
---------------------

Want to help improve Geary? Here are some ways to contribute:

 * Bug reporting: https://wiki.gnome.org/Apps/Geary/ReportingABug
 * Development:   https://wiki.gnome.org/Apps/Geary/Development
 * Translating:   https://wiki.gnome.org/Apps/Geary/Translating
 * Join the mailing list or IRC channel and join in the discussion

Getting in Touch
----------------

 * Geary wiki:   https://wiki.gnome.org/Apps/Geary
 * Mailing list: http://mail.gnome.org/mailman/listinfo/geary-list
 * IRC Channel:  [#geary on irc.gimp.org](irc://irc.gimp.org/%23geary)

---
Copyright 2016 Software Freedom Conservancy Inc.  
Copyright 2017 Michael Gratton <mike@vee.net>

==> geary_3.32.0.orig.tar.xz: geary-3.32.0/README.md <==

Geary: Send and receive email
=============================

![Geary icon](https://wiki.gnome.org/Apps/Geary?action=AttachFile&do=get&target=geary-3-32-256-logo.png)

Geary is an email application built around conversations, for the
GNOME 3 desktop. It allows you to read, find and send email with a
straightforward, modern interface.

Visit https://wiki.gnome.org/Apps/Geary for more information.

**GitHub users please note**: Bug reports, code contributions and
translations are managed using GNOME's infrastructure, so we cannot
accept tickets or pull requests on GitHub. Please see the links below
for more information.

![Geary displaying a conversation](https://wiki.gnome.org/Apps/Geary?action=AttachFile&amp;do=get&amp;target=geary-3-32-main-window.png)

Installation & Licensing
------------------------

Please consult the [INSTALL](./INSTALL) and [COPYING](./COPYING) files
for more information.

Contributing to Geary
---------------------

Want to help improve Geary? Here are some ways to contribute:

 * Bug reporting: https://wiki.gnome.org/Apps/Geary/ReportingABug
 * Development:   https://wiki.gnome.org/Apps/Geary/Development
 * Translating:   https://wiki.gnome.org/Apps/Geary/Translating
 * Join the mailing list or IRC channel and join in the discussion

Getting in Touch
----------------

 * Geary wiki:   https://wiki.gnome.org/Apps/Geary
 * Mailing list: http://mail.gnome.org/mailman/listinfo/geary-list
 * IRC Channel:  [#geary on irc.gimp.org](irc://irc.gimp.org/%23geary)

---
Copyright 2016 Software Freedom Conservancy Inc.  
Copyright 2017 Michael Gratton <mike@vee.net>
